create table ebdd_page_extended
(
    id bigint primary key ,
    create_time datetime,
    update_time datetime,
    creator bigint,
    delete_type int default 0 not null,
    tenant_key nvarchar(10),
    page_id bigint,
    belong_module nvarchar(50) not null,
    layout_type nvarchar(50) not null,
    ref_theme bigint,
    version_id nvarchar(50),
    is_lock int default 1 not null
)
GO

create index idx_ebdd_page_ext_tenantkey on ebdd_page_extended(tenant_key)
GO

create index idx_ebdd_page_ext_pageid on ebdd_page_extended(page_id)
GO



create table ebdd_page_layout
(
    id bigint primary key ,
    create_time datetime,
    update_time datetime,
    creator bigint,
    delete_type int default 0 not null,
    tenant_key nvarchar(10),
    page_id bigint,
    terminal_type nvarchar(50),
    config nvarchar(max),
    thumbnail nvarchar(50),
    source_code nvarchar(max),
    ecode_id bigint
)
GO

create index idx_page_layout_tenant_key on ebdd_page_layout(tenant_key)
GO

create index idx_page_layout_page_id on ebdd_page_layout(page_id)
GO


create table ebdd_layout_component
(
    id nvarchar(32) not null primary key ,
    create_time datetime,
    update_time datetime,
    creator bigint,
    delete_type int default 0 not null,
    tenant_key nvarchar(10),
    pid nvarchar(32),
    ref_comp_id nvarchar(32),
    type nvarchar(50),
    config nvarchar(max),
    layout_id bigint,
    master_component bigint,
    show_order int,
    is_lock int default 0,
    belong_user bigint
)
GO

create index idx_ebdd_layout_comp_tk on ebdd_layout_component(tenant_key)
GO

create index idx_ebdd_layout_comp_layoutid on ebdd_layout_component(layout_id)
GO

create index idx_layout_comp_master on ebdd_layout_component(master_component)
GO


create table ebdd_layout_component_setting
(
    id bigint not null primary key ,
    tenant_key nvarchar(10) not null,
    component_id nvarchar(32) not null,
    config nvarchar(max),
    belong_user bigint not null
)
GO

create index idx_ebdd_l_comp_s_tenant_key on ebdd_layout_component_setting(tenant_key)
GO

create index idx_ebdd_l_comp_s_belong_user on ebdd_layout_component_setting(belong_user)
GO



create table ebdd_layout_component_style
(
    id bigint not null primary key ,
    component_id nvarchar(32) not null,
    style_id bigint not null,
    tenant_key nvarchar(10)
)
GO

create index idx_ebdd_l_c_style_tenant_key on ebdd_layout_component_style(tenant_key)
GO

create index idx_ebdd_l_c_style_style_id on ebdd_layout_component_style(style_id)
GO

create index idx_ebdd_l_c_style_comp_id on ebdd_layout_component_style(component_id)
GO


create table ebdd_layout_component_right
(
    id bigint primary key ,
    create_time datetime,
    update_time datetime,
    creator bigint,
    delete_type int default 0,
    tenant_key nvarchar(10),
    comp_id nvarchar(32),
    right_type int
)
GO

create index ebdd_layout_c_right_tk on ebdd_layout_component_right(tenant_key)
GO


create table ebdd_eb_componentlogs
(
    id              bigint not null primary key,
    create_time     datetime2 default getdate(),
    update_time     datetime2 default getdate(),
    creator         bigint default '-1',
    delete_type     bigint    default 0,
    tenant_key      nvarchar(10),
    uuid            nvarchar(36),
    log_date        datetime2 default getdate(),
    device          nvarchar(500),
    log_operator    bigint default '-1',
    operatorname    nvarchar(100),
    targetid        bigint default '-1',
    targetname      nvarchar(3000),
    modulename      nvarchar(100),
    functionname    nvarchar(100),
    interfacename   nvarchar(100),
    requesturl      nvarchar(200),
    requesturi      nvarchar(200),
    operatetype     nvarchar(50),
    operatetypename nvarchar(100),
    operatedesc     nvarchar(3000),
    params          ntext,
    belongmainid    nvarchar(36),
    clientip        nvarchar(200),
    groupid         nvarchar(50),
    groupnamelabel  nvarchar(1000),
    redoservice     nvarchar(200),
    redocontext     nvarchar(3000),
    cancelservice   nvarchar(200),
    cancelcontext   nvarchar(3000),
    totalruntime    bigint default 0,
    mainruntime     bigint default 0,
    log_result      nvarchar(100),
    fromterminal    nvarchar(100),
    resultdesc      nvarchar(3000),
    old_content     nvarchar(3000),
    link_type       nvarchar(20),
    link_id         bigint default 0,
    old_link_id     bigint default 0
)
GO

create index idx_eb_complog_tk on ebdd_eb_componentlogs(tenant_key)
GO

create index idx_eb_complog_targetid on ebdd_eb_componentlogs(targetid)
GO

create index idx_eb_complog_modulename on ebdd_eb_componentlogs(modulename)
GO

create index idx_eb_complog_functionname on ebdd_eb_componentlogs(functionname)
GO


create table ebdd_eb_componentlogs_detail
(
    id bigint not null primary key,
    create_time     datetime2 default getdate(),
    update_time     datetime2 default getdate(),
    creator          bigint,
    delete_type      bigint,
    tenant_key       nvarchar(10),
    uuid             nvarchar(36),
    mainid           nvarchar(36),
    dataid           nvarchar(50),
    belongdataid     nvarchar(50),
    tableName        nvarchar(200),
    tablenamelabelid nvarchar(50),
    tablenamedesc    nvarchar(50),
    fieldName        nvarchar(200),
    fieldnamelabelid nvarchar(200),
    newValue         ntext,
    oldValue         ntext,
    newrealvalue     ntext,
    oldrealvalue     ntext,
    fieldDesc        varchar(200),
    showorder        bigint default 0,
    isdetail         bigint default 0
)
GO

create index idx_eb_complog_detail_tk on ebdd_eb_componentlogs_detail(tenant_key)
GO

create index idx_eb_complog_detail_uuid on ebdd_eb_componentlogs_detail(uuid)
GO

create index idx_eb_complog_detail_mainid on ebdd_eb_componentlogs_detail(uuid,mainid)
GO