create table ebdd_page_extended
(
    id bigint primary key ,
    create_time timestamp,
    update_time timestamp,
    creator bigint,
    delete_type int default 0 not null,
    tenant_key varchar(10),
    page_id bigint,
    belong_module varchar(50) not null,
    layout_type varchar(50) not null,
    ref_theme bigint,
    version_id varchar(50),
    is_lock int default 1 not null
);
/

create index idx_ebdd_page_ext_tenantkey on ebdd_page_extended(tenant_key);
/

create index idx_ebdd_page_ext_pageid on ebdd_page_extended(page_id);
/



create table ebdd_page_layout
(
    id bigint primary key ,
    create_time timestamp,
    update_time timestamp,
    creator bigint,
    delete_type int default 0 not null,
    tenant_key varchar(10),
    page_id bigint,
    terminal_type varchar(50),
    config text,
    thumbnail varchar(50),
    source_code text,
    ecode_id bigint
);
/

create index idx_page_layout_tenant_key on ebdd_page_layout(tenant_key);
/

create index idx_page_layout_page_id on ebdd_page_layout(page_id);
/


create table ebdd_layout_component
(
    id varchar(32) not null primary key ,
    create_time timestamp,
    update_time timestamp,
    creator bigint,
    delete_type int default 0 not null,
    tenant_key varchar(10),
    pid varchar(32),
    ref_comp_id varchar(32),
    type varchar(50),
    config text,
    layout_id bigint,
    master_component bigint,
    show_order int,
    is_lock int default 0,
    belong_user bigint
);
/

create index idx_ebdd_layout_comp_tk on ebdd_layout_component(tenant_key);
/

create index idx_ebdd_layout_comp_layoutid on ebdd_layout_component(layout_id);
/

create index idx_layout_comp_master on ebdd_layout_component(master_component);
/


create table ebdd_layout_component_setting
(
    id bigint not null primary key ,
    tenant_key varchar(10) not null,
    component_id varchar(32) not null,
    config text,
    belong_user bigint not null
);
/

create index idx_ebdd_l_comp_s_tenant_key on ebdd_layout_component_setting(tenant_key);
/

create index idx_ebdd_l_comp_s_belong_user on ebdd_layout_component_setting(belong_user);
/



create table ebdd_layout_component_style
(
    id bigint not null primary key ,
    component_id varchar(32) not null,
    style_id bigint not null,
    tenant_key varchar(10)
);
/

create index idx_ebdd_l_c_style_tenant_key on ebdd_layout_component_style(tenant_key);
/

create index idx_ebdd_l_c_style_style_id on ebdd_layout_component_style(style_id);
/

create index idx_ebdd_l_c_style_comp_id on ebdd_layout_component_style(component_id);
/

create table ebdd_layout_component_right
(
    id bigint primary key ,
    create_time timestamp,
    update_time timestamp,
    creator bigint,
    delete_type int default 0,
    tenant_key varchar(10),
    comp_id varchar(32),
    right_type int
);
/

create index ebdd_layout_c_right_tk on ebdd_layout_component_right(tenant_key);
/


create table ebdd_eb_componentlogs
(
    id              int8 not null primary key,
    create_time     timestamp default current_timestamp,
    update_time     timestamp default current_timestamp,
    creator         int8,
    delete_type     int,
    tenant_key      varchar(10),
    uuid            varchar(36),
    log_date        timestamp default current_timestamp,
    log_operator    varchar(50),
    operatorName    varchar(50),
    targetId        varchar(50),
    targetName      text,
    modulename      varchar(100),
    functionname    varchar(100),
    interfaceName   varchar(100),
    requesturl      varchar(200),
    requesturi      varchar(200),
    operateType     varchar(50),
    operatetypename varchar(100),
    operatedesc     varchar(1000),
    params          text,
    belongmainid    varchar(36),
    clientIp        varchar(200),
    groupid         varchar(50),
    device          varchar(200),
    groupNameLabel  varchar(500),
    redoService     varchar(200),
    redoContext     text,
    cancelService   varchar(200),
    cancelContext   text,
    totalruntime    int4,
    mainruntime     int4,
    log_result      varchar(100),
    fromterminal    varchar(100),
    resultdesc      text,
    old_content     varchar(1000),
    link_type       varchar(20),
    link_id         int4,
    old_link_id     int4
);
/

create index idx_eb_complog_tk on ebdd_eb_componentlogs(tenant_key);
/

create index idx_eb_complog_targetid on ebdd_eb_componentlogs(targetid);
/

create index idx_eb_complog_modulename on ebdd_eb_componentlogs(modulename);
/

create index idx_eb_complog_functionname on ebdd_eb_componentlogs(functionname);
/



create table ebdd_eb_componentlogs_detail
(
    id               int8 not null primary key,
    create_time      timestamp default current_timestamp ,
    update_time      timestamp default current_timestamp ,
    creator          int8,
    delete_type      int8,
    tenant_key       varchar(10),
    uuid             varchar(36),
    mainid           varchar(36),
    dataid           varchar(50),
    belongdataid     varchar(50),
    tableName        varchar(200),
    tablenamelabelid varchar(50),
    tablenamedesc    varchar(50),
    fieldName        varchar(200),
    fieldnamelabelid varchar(200),
    newValue         text,
    oldValue         text,
    newrealvalue     text,
    oldrealvalue     text,
    fieldDesc        varchar(200),
    showorder        int8 default 0,
    isdetail         int8 default 0
);
/

create index idx_eb_complog_detail_tk on ebdd_eb_componentlogs_detail(tenant_key);
/

create index idx_eb_complog_detail_uuid on ebdd_eb_componentlogs_detail(uuid);
/

create index idx_eb_complog_detail_mainid on ebdd_eb_componentlogs_detail(uuid,mainid);
/