create table ebdd_page_extended
(
    id number primary key ,
    create_time date,
    update_time date,
    creator number,
    delete_type int default 0 not null,
    tenant_key varchar2(10),
    page_id number,
    belong_module varchar2(50) not null,
    layout_type varchar2(50) not null,
    ref_theme number,
    version_id varchar2(50),
    is_lock int default 1 not null
);
/

create index idx_ebdd_page_ext_tenantkey on ebdd_page_extended(tenant_key);
/

create index idx_ebdd_page_ext_pageid on ebdd_page_extended(page_id);
/

create table ebdd_page_layout
(
    id number primary key ,
    create_time date,
    update_time date,
    creator number,
    delete_type int default 0 not null,
    tenant_key varchar2(10),
    page_id number,
    terminal_type varchar2(50),
    config clob,
    thumbnail varchar2(50),
    source_code clob,
    ecode_id number
);
/

create index idx_page_layout_tenant_key on ebdd_page_layout(tenant_key);
/

create index idx_page_layout_page_id on ebdd_page_layout(page_id);
/

create table ebdd_layout_component
(
    id varchar2(32) not null primary key ,
    create_time date,
    update_time date,
    creator number,
    delete_type int default 0 not null,
    tenant_key varchar2(10),
    pid varchar2(32),
    ref_comp_id varchar2(32),
    type varchar2(50),
    config clob,
    layout_id number,
    master_component number,
    show_order int,
    is_lock int default 0,
    belong_user number
);
/

create index idx_ebdd_layout_comp_tk on ebdd_layout_component(tenant_key);
/

create index idx_ebdd_layout_comp_layoutid on ebdd_layout_component(layout_id);
/

create index idx_layout_comp_master on ebdd_layout_component(master_component);
/

create table ebdd_layout_component_setting
(
    id number not null primary key ,
    tenant_key varchar2(10) not null,
    component_id varchar2(32) not null,
    config clob,
    belong_user number not null
);
/

create index idx_ebdd_l_comp_s_tenant_key on ebdd_layout_component_setting(tenant_key);
/

create index idx_ebdd_l_comp_s_belong_user on ebdd_layout_component_setting(belong_user);
/

create table ebdd_layout_component_style
(
    id number not null primary key ,
    component_id varchar2(32) not null,
    style_id number not null,
    tenant_key varchar2(10)
);
/

create index idx_ebdd_l_c_style_tenant_key on ebdd_layout_component_style(tenant_key);
/

create index idx_ebdd_l_c_style_style_id on ebdd_layout_component_style(style_id);
/

create index idx_ebdd_l_c_style_comp_id on ebdd_layout_component_style(component_id);
/

create table ebdd_layout_component_right
(
    id number primary key ,
    create_time date,
    update_time date,
    creator number,
    delete_type int default 0,
    tenant_key varchar2(10),
    comp_id varchar2(32),
    right_type int
);
/

create index ebdd_layout_c_right_tk on ebdd_layout_component_right(tenant_key);
/

create table ebdd_eb_componentlogs
(
    id              number(*,0) not null,
    create_time     date default sysdate,
    update_time     date default sysdate,
    creator         number(*,0),
    delete_type     number(*,0),
    tenant_key      varchar2(10),
    uuid            varchar2(36),
    log_date        date default sysdate,
    log_operator    varchar2(50),
    operatorName    varchar2(50),
    targetId        varchar2(50),
    targetName      varchar2(4000),
    modulename      varchar2(100),
    functionname    varchar2(100),
    interfaceName   varchar2(100),
    requesturl      varchar2(200),
    requesturi      varchar2(200),
    operateType     varchar2(50),
    operatetypename varchar2(100),
    operatedesc     varchar2(1000),
    params          clob,
    belongmainid    varchar2(36),
    clientIp        varchar2(200),
    groupid         varchar2(50),
    device          varchar2(200),
    groupNameLabel  varchar2(500),
    redoService     varchar2(200),
    redoContext     varchar2(4000),
    cancelService   varchar2(200),
    cancelContext   varchar2(4000),
    totalruntime    number(*,0),
    mainruntime     number(*,0),
    log_result      varchar2(4000),
    fromterminal    varchar2(100),
    resultdesc      varchar2(4000),
    old_content     varchar2(1000),
    link_type       varchar2(20),
    link_id         number(*,0),
    old_link_id     number(*,0),
    PRIMARY KEY (id)
);
/

create index idx_eb_complog_tk on ebdd_eb_componentlogs(tenant_key);
/

create index idx_eb_complog_targetid on ebdd_eb_componentlogs(targetid);
/

create index idx_eb_complog_modulename on ebdd_eb_componentlogs(modulename);
/

create index idx_eb_complog_functionname on ebdd_eb_componentlogs(functionname);
/

create table ebdd_eb_componentlogs_detail
(
    id               number(*,0) not null,
    create_time      date default sysdate,
    update_time      date default sysdate,
    creator          number(*,0),
    delete_type      number(*,0),
    tenant_key       varchar2(10),
    uuid             varchar2(36),
    mainid           varchar2(36),
    dataid           varchar2(50),
    belongdataid     varchar2(50),
    tableName        varchar2(200),
    tablenamelabelid varchar2(50),
    tablenamedesc    varchar2(50),
    fieldName        varchar2(200),
    fieldnamelabelid varchar2(200),
    newValue         varchar2(4000),
    oldValue         varchar2(4000),
    newrealvalue     varchar2(4000),
    oldrealvalue     varchar2(4000),
    fieldDesc        varchar2(200),
    showorder        number(*,0) default 0,
    isdetail         number(*,0) default 0
);
/

create index idx_eb_complog_detail_tk on ebdd_eb_componentlogs_detail(tenant_key);
/

create index idx_eb_complog_detail_uuid on ebdd_eb_componentlogs_detail(uuid);
/

create index idx_eb_complog_detail_mainid on ebdd_eb_componentlogs_detail(uuid,mainid);
/