create table ebdd_page_extended
(
    id bigint primary key  comment 'ID' ,
    create_time datetime comment '创建时间' ,
    update_time datetime comment '修改时间' ,
    creator bigint comment '创建人id' ,
    delete_type int default 0 not null comment '是否删除' ,
    tenant_key varchar(10) comment '租户KEY' ,
    page_id bigint comment '页面id' ,
    belong_module varchar(50) not null comment '所属模块' ,
    layout_type varchar(50) not null comment '布局类型' ,
    ref_theme bigint comment '关联主题' ,
    version_id varchar(50) comment '版本号' ,
    is_lock int default 1 not null comment '是否锁定'
)
;

create index idx_ebdd_page_ext_tenantkey on ebdd_page_extended(tenant_key)
;

create index idx_ebdd_page_ext_pageid on ebdd_page_extended(page_id)
;



create table ebdd_page_layout
(
    id bigint primary key  comment 'ID' ,
    create_time datetime comment '创建时间' ,
    update_time datetime comment '修改时间' ,
    creator bigint comment '创建人id' ,
    delete_type int default 0 not null comment '是否删除' ,
    tenant_key varchar(10) comment '租户KEY' ,
    page_id bigint comment '页面id' ,
    terminal_type varchar(50) comment '客户端类型' ,
    config longtext comment '布局配置' ,
    thumbnail varchar(50) comment '缩略图' ,
    source_code longtext comment '源码' ,
    ecode_id bigint comment 'ecodeId'
)
;

create index idx_page_layout_tenant_key on ebdd_page_layout(tenant_key)
;

create index idx_page_layout_page_id on ebdd_page_layout(page_id)
;


create table ebdd_layout_component
(
    id varchar(32) not null primary key  comment 'ID' ,
    create_time datetime comment '创建时间' ,
    update_time datetime comment '修改时间' ,
    creator bigint comment '创建人id' ,
    delete_type int default 0 not null comment '是否删除' ,
    tenant_key varchar(10) comment '租户KEY' ,
    pid varchar(32) comment '父id' ,
    ref_comp_id varchar(32) comment '关联组件id' ,
    type varchar(50) comment '组件类型' ,
    config longtext comment '组件配置' ,
    layout_id bigint comment '布局id' ,
    master_component bigint comment '母版id' ,
    show_order int comment '显示顺序' ,
    is_lock int default 0 comment '锁定' ,
    belong_user bigint comment '自定义组件-所属用户'
)
;

create index idx_ebdd_layout_comp_tk on ebdd_layout_component(tenant_key)
;

create index idx_ebdd_layout_comp_layoutid on ebdd_layout_component(layout_id)
;

create index idx_layout_comp_master on ebdd_layout_component(master_component)
;



create table ebdd_layout_component_setting
(
    id bigint not null primary key  comment 'ID' ,
    tenant_key varchar(10) not null comment '租户KEY' ,
    component_id varchar(32) not null comment '组件id' ,
    config text comment '组件设置' ,
    belong_user bigint not null comment '所属用户'
)
;

create index idx_ebdd_l_comp_s_tenant_key on ebdd_layout_component_setting(tenant_key)
;

create index idx_ebdd_l_comp_s_belong_user on ebdd_layout_component_setting(belong_user)
;



create table ebdd_layout_component_style
(
    id bigint not null primary key  comment 'ID' ,
    component_id varchar(32) not null comment '组件id' ,
    style_id bigint not null comment '样式id' ,
    tenant_key varchar(10) comment '租户key'
)
;

create index idx_ebdd_l_c_style_tenant_key on ebdd_layout_component_style(tenant_key)
;

create index idx_ebdd_l_c_style_style_id on ebdd_layout_component_style(style_id)
;

create index idx_ebdd_l_c_style_comp_id on ebdd_layout_component_style(component_id)
;

create table ebdd_layout_component_right
(
    id bigint primary key  comment 'ID' ,
    create_time datetime comment '创建时间' ,
    update_time datetime comment '修改时间' ,
    creator bigint comment '创建人id' ,
    delete_type int default 0 comment '是否删除' ,
    tenant_key varchar(10) comment '租户KEY' ,
    comp_id varchar(32) comment '组件id' ,
    right_type int comment '权限类型'
)
;

create index ebdd_layout_c_right_tk on ebdd_layout_component_right(tenant_key)
;


create table ebdd_eb_componentlogs
(
    id              bigint comment 'ID',
    create_time     datetime default current_timestamp ,
    update_time     datetime default current_timestamp ,
    creator         bigint,
    delete_type     int,
    tenant_key      varchar(10),
    uuid            char(36),
    log_date        datetime default current_timestamp ,
    log_operator    varchar(50),
    operatorName    varchar(50),
    targetId        varchar(50),
    targetName      text,
    modulename      varchar(100),
    functionname    varchar(100),
    interfaceName   varchar(100),
    requesturl      varchar(200),
    requesturi      varchar(200),
    operateType     varchar(50),
    operatetypename varchar(100),
    operatedesc     varchar(1000),
    params          longtext,
    belongmainid    varchar(36),
    clientIp        varchar(50),
    groupid         varchar(50),
    device          varchar(200),
    groupNameLabel  varchar(500),
    redoService     varchar(200),
    redoContext     longtext,
    cancelService   varchar(200),
    cancelContext   longtext,
    totalruntime    bigint,
    mainruntime     bigint,
    log_result      varchar(100),
    fromterminal    varchar(100),
    resultdesc      text,
    old_content     varchar(1000),
    link_type       varchar(20),
    link_id         bigint,
    old_link_id     bigint,
    PRIMARY KEY (id)
)
;

create index idx_eb_complog_tk on ebdd_eb_componentlogs(tenant_key)
;

create index idx_eb_complog_targetid on ebdd_eb_componentlogs(targetid)
;

create index idx_eb_complog_modulename on ebdd_eb_componentlogs(modulename)
;

create index idx_eb_complog_functionname on ebdd_eb_componentlogs(functionname)
;



create table ebdd_eb_componentlogs_detail
(
    id               bigint not null primary key,
    create_time      datetime default current_timestamp ,
    update_time      datetime default current_timestamp ,
    creator          bigint,
    delete_type      int,
    tenant_key       varchar(10),
    uuid             varchar(36),
    mainid           varchar(36),
    dataid           varchar(50),
    belongdataid     varchar(50),
    tableName        varchar(200),
    tablenamelabelid varchar(50),
    tablenamedesc    varchar(50),
    fieldName        varchar(200),
    fieldnamelabelid varchar(200),
    newValue         longtext,
    oldValue         longtext,
    newrealvalue     longtext,
    oldrealvalue     longtext,
    fieldDesc        varchar(200),
    showorder        int default 0,
    isdetail         int default 0
)
;

create index idx_eb_complog_detail_tk on ebdd_eb_componentlogs_detail(tenant_key)
;

create index idx_eb_complog_detail_uuid on ebdd_eb_componentlogs_detail(uuid)
;

create index idx_eb_complog_detail_mainid on ebdd_eb_componentlogs_detail(uuid,mainid)
;